==> karchiver-3.1.1.tar.bz2: karchiver-3.1.1/karchiver/cajoutfichiers.h <==
/***************************************************************************
                          cajoutfichiers.h  -  description
                             -------------------
    begin                : Thu Jun 3 1999
    copyright            : (C) 2000 by Eric Coquelle
    email                : coquelle@caramail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CAddFilesToArchive_included
#define CAddFilesToArchive_included

#include <qdialog.h>
#include <qdir.h>
#include <qfiledialog.h>
#include <qlistview.h>
#include <qradiobutton.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qbuttongroup.h>
#include <qtextedit.h>

#include <kapp.h>
#include <klocale.h>
#include <kfiledialog.h>

#include "dirview.h"

/* The list class
	It has to handle mouse events for the multiselection tree view */
	
class liste : public QListView
{
	Q_OBJECT
	
public:
	liste (QWidget*, const char*);

public slots:  
  void checkSelectionChanged();

signals:
	void selectionChangee(QListViewItem*);
};

class textEdit : public QTextEdit
{
        Q_OBJECT
public:
        textEdit (QWidget*, const char*);

protected:
        virtual void contentsDropEvent(QDropEvent*);
        virtual void contentsDragEnterEvent(QDragEnterEvent* event);
signals:
        void newFilesAdded(QStringList);
};

/* The CAddFilesToArchive class. It provides a dialog box
	for adding some files to currently loaded archive. It
	only return a QStrList containing the files to be added */
	
class CAddFilesToArchive : public QDialog
{
    Q_OBJECT

public:

    CAddFilesToArchive
    (
        QDialog *parent = 0,
        const char* name = 0
    );

    virtual ~CAddFilesToArchive();

	void rebuildPath(QListViewItem*);
	QStrList getFichiers();
	int getAction();
	/* Return true if source files should be removed */
	bool getRemoveFiles();

public slots:
	void OK();
	void Cancel();
	void selectionneMotif(int);
	void MAJMotif();
	void slotSelectionModifiee(QListViewItem*);
        void newFiles(QStringList);

protected:
	liste* listView;
	Directory *directory;
	QRadioButton* qtarch_RadioAjoute;
	QRadioButton* qtarch_RadioUpdate;
	QRadioButton* qtarch_RadioMotif;
	QCheckBox* qtarch_CheckBox;
	textEdit* qtarch_LineFichiers;
	QString path;
	QStrList filelist;
        QPixmap pix;

private:
};

#endif // CAddFilesToArchive_included

==> karchiver-3.4.2.b4.tar.bz2: karchiver-3.4.2.b4/karchiver/cajoutfichiers.h <==
/***************************************************************************
                          cajoutfichiers.h  -  description
                             -------------------
    begin                : Thu Jun 3 1999
    copyright            : (C) 2000 by Eric Coquelle
    email                : coquelle@caramail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _CADDFILESTOARCHIVE_
#define _CADDFILESTOARCHIVE_

#include <qdialog.h>
#include <qdir.h>
#include <qfiledialog.h>
#include <qlistview.h>
#include <qradiobutton.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <qbuttongroup.h>
#include <qtextedit.h>

#include <kapp.h>
#include <klocale.h>
#include <kfiledialog.h>
#include <klistview.h>

#include "dirview.h"
#include "resource.h"

/* The CAddFilesToArchive class. It provides a dialog box
	for adding some files to currently loaded archive. It
	 returns a QStrList containing the files to be added,
         and getAction to tell if the files should replace or update
         archive's data*/
	
class CAddFilesToArchive : public QDialog
{
    Q_OBJECT

public:

    CAddFilesToArchive
    (
        QDialog *parent = 0,
        const char* name = 0
    );

    virtual ~CAddFilesToArchive();

        /*Returns a list of all files that have to be added to current archive*/
	QStrList getFiles();
        /*Return ADD_AND_REPLACE_FILES -0- to replace files in current archive, or UPDATE_FILES -1-*/
	int getAction();
	/* Return true if source files should be removed */
	bool hasToRemoveFiles();

private:
  void rebuildPath(QListViewItem*);
  
private slots:
	void OK();
	void Cancel();
	void selectionneMotif(int);
        void slotSelectionChanged(QListViewItem*);
        void slotGetFilesFromDialogBox();

  private:
    KListView* listView;
	Directory *directory;
	QRadioButton* qtarch_RadioAdd;
	QRadioButton* qtarch_RadioUpdate;
	QPushButton* qtarch_Motif;
	QCheckBox* qtarch_CheckBox;
	QTextEdit* qtarch_LineFichiers;
	QString path;
	QStrList filelist;
};

#endif
